@@ -81,9 +81,8 @@ impl<I> Parser<'_, I> where I: Iterator<Item=Result<TokenMeta, LexerError>> {
             }
         }
         
-        // This craziness is needed to finagle a reference in one branch 
-        // while advancing the token iterator and taking ownership of the ParserError in the other
-        // otherwise the borrow checker will have a heart attack over the immutable borrow in &mut self.
+        // This is needed to finagle a reference in one branch while advancing the 
+        // token iterator and taking ownership of the ParserError in the other
         if self.next.as_ref().unwrap().is_ok() {
             Ok(self.next.as_ref().unwrap().as_ref().unwrap()) // yes, the repetition is required
         } else {
@@ -240,7 +239,7 @@ impl<I> Parser<'_, I> where I: Iterator<Item=Result<TokenMeta, LexerError>> {
             
             Token::Loop => self.parse_loop(ctx, None)?,
             Token::While => self.parse_while_loop(ctx, None)?,
-            Token::For => unimplemented!(),
+            Token::For => self.parse_for_loop(ctx, None)?,
             
             Token::Label(..) => self.parse_stmt_label(ctx)?,
             
@@ -284,7 +283,7 @@ impl<I> Parser<'_, I> where I: Iterator<Item=Result<TokenMeta, LexerError>> {
         match self.peek()?.token {
             Token::Loop => self.parse_loop(ctx, Some(label)),
             Token::While => self.parse_while_loop(ctx, Some(label)),
-            Token::For => unimplemented!(),
+            Token::For => self.parse_for_loop(ctx, Some(label)),
             
             _ => Err("labels must be followed by either a block or a loop".into()),
         }
@@ -330,6 +329,62 @@ impl<I> Parser<'_, I> where I: Iterator<Item=Result<TokenMeta, LexerError>> {
         Ok(Stmt::WhileLoop { label, condition, body })
     }
     
+    fn parse_for_loop(&mut self, ctx: &mut ErrorContext, label: Option<Label>) -> ParseResult<Stmt> {
+        let next = self.advance()?;
+        
+        ctx.push(ContextTag::ForLoop);
+        ctx.set_start(&next);
+        debug_assert!(matches!(next.token, Token::For));
+        
+        // parse lvalue list
+        let lvalue = self.parse_lvalue_list(ctx)?;
+        
+        let next = self.advance()?;
+        ctx.set_end(&next);
+        
+        if !matches!(next.token, Token::In) {
+            return Err("expected \"do\" after condition in while-loop".into());
+        }
+        
+        // parse iterator expression
+        let iter = self.parse_expr_variant(ctx)?;
+        
+        let next = self.advance()?;
+        ctx.set_end(&next);
+        
+        if !matches!(next.token, Token::Do) {
+            return Err("expected \"do\" after condition in while-loop".into());
+        }
+        
+        let body = self.parse_stmt_list(ctx, |token| matches!(token, Token::End))?;
+        
+        ctx.set_end(&self.advance().unwrap()); // consume "end"
+        
+        let for_loop = Stmt::ForLoop {
+            label,
+            lvalue,
+            iter,
+            body,
+        };
+        
+        ctx.pop_extend();
+        Ok(for_loop)
+    }
+    
+    fn parse_lvalue_list(&mut self, ctx: &mut ErrorContext) -> ParseResult<LValue> {
+        let modifier = self.try_parse_assign_keyword(ctx)?;
+        
+        let lvalue = self.parse_tuple_expr(ctx)?
+            .try_into()
+            .map_err(|_| ParserError::from("can't assign to this"))?;
+        
+        if let Some(modifier) = modifier {
+            Ok(LValue::Modifier { modifier, lvalue: Box::new(lvalue) })
+        } else {
+            Ok(lvalue)
+        }
+    }
+    
     /// Parses a list of statements, stopping when the given closure returns true. The final token is not consumed.
     fn parse_stmt_list(&mut self, ctx: &mut ErrorContext, end_list: impl Fn(&Token) -> bool) -> ParseResult<StmtList> {
         ctx.push(ContextTag::StmtList);
@@ -756,6 +811,7 @@ impl<I> Parser<'_, I> where I: Iterator<Item=Result<TokenMeta, LexerError>> {
         // check for plain ellipsis
         let next = self.peek()?;
         if matches!(next.token, Token::Ellipsis) {
+            ctx.set_end(&self.advance().unwrap());
             return Ok(Expr::Ellipsis(None));
         }
         
