@@ -90,21 +90,29 @@ impl Namespace {
 
 /// Mutable container for storing a Namespace in a Gc.
 #[derive(Debug, Default, Clone)]
-pub struct GlobalEnv {
+pub struct NamespaceEnv {
     namespace: RefCell<Namespace>,
 }
 
-impl From<Namespace> for GlobalEnv {
+impl From<Namespace> for NamespaceEnv {
     fn from(namespace: Namespace) -> Self {
         Self { namespace: RefCell::new(namespace) }
     }
 }
 
-impl GlobalEnv {
+impl NamespaceEnv {
     pub fn new() -> Gc<Self> {
         Gc::new(Self::default())
     }
     
+    pub fn take(self) -> Namespace {
+        self.namespace.take()
+    }
+    
+    pub fn get_mut(&mut self) -> &mut Namespace {
+        self.namespace.get_mut()
+    }
+    
     pub fn borrow(&self) -> Ref<Namespace> {
         self.namespace.borrow()
     }
@@ -114,7 +122,7 @@ impl GlobalEnv {
     }
 }
 
-unsafe impl GcTrace for GlobalEnv {
+unsafe impl GcTrace for NamespaceEnv {
     fn trace(&self) {
         for value in self.namespace.borrow().values() {
             value.trace();
@@ -129,7 +137,7 @@ pub struct Module {
     display: String,
     source: Option<ModuleSource>,
     data: ProgramData,
-    globals: Gc<GlobalEnv>,
+    globals: Gc<NamespaceEnv>,
 }
 
 unsafe impl GcTrace for Module {
@@ -140,11 +148,11 @@ unsafe impl GcTrace for Module {
 
 impl Module {
     pub fn allocate(source: Option<ModuleSource>, data: ProgramData) -> Gc<Self> {
-        let globals = GlobalEnv::new();
+        let globals = NamespaceEnv::new();
         Self::with_env(source, data, globals)
     }
     
-    pub fn with_env(source: Option<ModuleSource>, data: ProgramData, globals: Gc<GlobalEnv>) -> Gc<Self> {
+    pub fn with_env(source: Option<ModuleSource>, data: ProgramData, globals: Gc<NamespaceEnv>) -> Gc<Self> {
         let ident = 
             if let Some(source) = source.as_ref() { ModuleIdent::from(source) }
             else { ModuleIdent::from(globals) };
@@ -170,7 +178,7 @@ impl Module {
     pub fn data(&self) -> &ProgramData { &self.data }
     
     #[inline(always)]
-    pub fn globals(&self) -> Gc<GlobalEnv> { self.globals }
+    pub fn globals(&self) -> Gc<NamespaceEnv> { self.globals }
     
     #[inline]
     pub fn get_const(&self, cid: ConstID) -> Variant {
@@ -230,10 +238,10 @@ impl From<&ModuleSource> for ModuleIdent {
     }
 }
 
-impl From<Gc<GlobalEnv>> for ModuleIdent {
-    fn from(env: Gc<GlobalEnv>) -> Self {
+impl From<Gc<NamespaceEnv>> for ModuleIdent {
+    fn from(env: Gc<NamespaceEnv>) -> Self {
         let mut state = MODULE_IDENT_HASH.build_hasher();
-        <Gc<GlobalEnv> as Hash>::hash(&env, &mut state);
+        <Gc<NamespaceEnv> as Hash>::hash(&env, &mut state);
         let hash = state.finish();
         Self::RefHash(hash)
     }
