@@ -13,7 +13,11 @@ pub use buffer::StrBuffer;
 use intern::StringTable;
 
 
-#[cfg(target_arch = "x86_64")]
+// need to build on a 32-bit machine to find out what will fit
+#[cfg(target_pointer_width = "32")]
+pub type InlineStr = StrBuffer<4>;
+
+#[cfg(target_pointer_width = "64")]
 pub type InlineStr = StrBuffer<14>;
 
 #[derive(Debug, Clone, Copy)]
