@@ -1,7 +1,7 @@
 use std::path::Path;
 
 use sphinx;
-use sphinx::stdlib;
+use sphinx::builtins;
 use sphinx::source::ModuleSource;
 use sphinx::codegen::{Program, CompiledProgram};
 use sphinx::runtime::{Module, VirtualMachine};
@@ -25,7 +25,7 @@ fn run_test_script(path: &Path) -> ExecResult<()> {
     
     let program = Program::load(build.program);
     
-    let main_env = stdlib::create_prelude();
+    let main_env = builtins::create_prelude();
     let main_module = Module::with_env(Some(source), program.data, main_env);
     
     let vm = VirtualMachine::new(main_module, &program.main);
@@ -77,12 +77,21 @@ mod tuple_tests {
     use super::*;
     
     test_script!(assignment, "tests/tuple/assignment.sph");
+    test_script!(comparison, "tests/tuple/comparison.sph");
 }
 
 mod while_tests {
     use super::*;
     
     test_script!(while_, "tests/while/while.sph");
+    test_script!(continue_, "tests/while/continue.sph");
+}
+
+mod for_tests {
+    use super::*;
+    
+    test_script!(for_, "tests/for/for.sph");
+    test_script!(continue_, "tests/for/continue.sph");
 }
 
 mod variable_tests {
@@ -103,6 +112,7 @@ mod function_tests {
     test_script!(nested_call_with_arguments, "tests/function/nested_call_with_arguments.sph");
     test_script!(inner_block, "tests/function/inner_block.sph");
     test_script!(missing_arguments, "tests/function/missing_arguments.sph", error: ErrorKind::MissingArguments {..});
+    test_script!(argument_unpack, "tests/function/argument_unpack.sph");
 }
 
 mod closure_tests {
